
var JaLF	= String.fromCharCode(0x0A);		// 改行コード(0x0A)を定義する。
var JaESC	= String.fromCharCode(0x1B);		// ESCシーケンスコード(0x1B)を定義する。
	
function WDMake(){
	var Work ='';
	var Name ='';
	with (parent.SubMain.document.FrontPage_Form1) {
		// ポーリング実行
		Rtn = PCCAx.pcxReceiveResponse(0, 3000);
		APIReturnCode(Rtn);

		// 'DT'コマンド実行(ﾄﾗｯｸ1)
		PCCAx.SendData = 'DT:1';
		Rtn = PCCAx.pcxSendCommandRR(1, 3000);
		APIReturnCode(Rtn);

		Tr1 = PCCAx.PollCmdResData;

		// ポーリング実行
		Rtn = PCCAx.pcxReceiveResponse(0, 3000);
		APIReturnCode(Rtn);

		// Tr1 データ設定(会員番号 + 名前 + 最終カード利用日)
		Name = PCCAx.pcxJISconvSJIS(1,PCCAx.pcxCharAscHConv(0,TxtName.value));	// "松下" -> "8FBC89BA" -> "3E3E323C"
		Work = Work + LRAsciiSpcFill(FRTrim(PCCAx.pcxCharAscHConv(0,TxtKanin.value)),40,1); 		// 会員番号
		Work = Work + LRAsciiSpcFill(FRTrim(Name),48,1);											// 氏名
		Work = Work + LRAsciiSpcFill(FRTrim(PCCAx.pcxCharAscHConv(0,TxtRiyoubi.value)),40,1);		// 利用日
		Work = Work + CharFill(0x30,136 - getByteCount(Work));
		Work = Work + PCCAx.pcxDataSumCalc(Work);
		Work =  'WD:1/' + Work ;

		// 'WD'コマンド実行
//		alert('Work= ' + Work + '\n' + 'getByteCount=' + getByteCount(Work));
//		alert(getByteCount(Work));
		PCCAx.SendData = Work;
		Rtn = PCCAx.pcxSendCommandRR(1, 3000);
		APIReturnCode(Rtn);
//		alert('pcxSendCommandRR　WD:1　ComSts='+PCCAx.PollCmdComSts+'  Err='+PCCAx.PollCmdErr);


		// Tr2 データ設定
		Work = '';
		Work = '30' + parent.SubMenu.document.FormSubM.MediaKindTxtBox.value + 'AAA'; 
		Work = Work + CharFill(0x46,136 - getByteCount(Work));
		Work = Work + PCCAx.pcxDataSumCalc(Work);
		Work =  'WD:2/' + Work ;
//		alert('WD:2 = ' + Work);

		// 'WD'コマンド実行
//		alert('Work= ' + Work + '\n' + 'getByteCount=' + getByteCount(Work));
		PCCAx.SendData = Work;
		Rtn = PCCAx.pcxSendCommandRR(1, 3000);
		APIReturnCode(Rtn);
//		alert('pcxSendCommandRR　WD:2　ComSts='+PCCAx.PollCmdComSts+' Err='+PCCAx.PollCmdErr);

		// Tr3 データ設定(発行日 + 今回ﾎﾟｲﾝﾄ + 累計ﾎﾟｲﾝﾄ + 来店回数)
		Work = '';
		Work = Work + LRAsciiSpcFill(FRTrim(PCCAx.pcxCharAscHConv(0,TxtHakkoubi.value)),40,1);		// 発行日
		Work = Work + LRAsciiSpcFill(FRTrim(PCCAx.pcxCharAscHConv(0,TxtKonkaiPoint.value)),14,1);	// 今回ﾎﾟｲﾝﾄ
		Work = Work + LRAsciiSpcFill(FRTrim(PCCAx.pcxCharAscHConv(0,TxtRuikeiPoint.value)),14,1);	// 累計ﾎﾟｲﾝﾄ
		Work = Work + LRAsciiSpcFill(''+eval(PCCAx.pcxCharAscHConv(0,TxtRiyouKaisu.value)),4,1);	// 来店回数
		Work = Work + CharFill(0x30,136 - getByteCount(Work));
		Work = Work + PCCAx.pcxDataSumCalc(Work);
		Work =  'WD:3/' + Work ;

		// 'WD'コマンド実行
//		alert('Work= ' + Work + '\n' + 'getByteCount=' + getByteCount(Work));
		PCCAx.SendData = Work;
		Rtn = PCCAx.pcxSendCommandRR(1, 3000);
		APIReturnCode(Rtn);
//		alert('pcxSendCommandRR　WD:3　ComSts='+PCCAx.PollCmdComSts+' Err='+PCCAx.PollCmdErr);
	}
}

function PDMake(){
	var Work ='';
	with (parent.SubMain.document.FrontPage_Form1) {
		// PCCAx.SendData = 'MS:N0X0Y6H4C4K0F1';
		// Rtn = PCCAx.pcxSendCommandRR(1, 3000);
		// APIReturnCode(Rtn)
		
		PCCAx.SendData = 'PC';
		Rtn = PCCAx.pcxSendCommandRR(1, 3000);
		APIReturnCode(Rtn)
		
		Rtn = PCCAx.pcxReceiveResponse(0, 3000);
		APIReturnCode(Rtn)
		// alert('pcxReceiveResponse = ' + Rtn);
		
		Work = 'PD:0/0/26/' + TxtKoum0.value + LRSpcFill(FRTrim(TxtKanin.value),20,1) + JaLF;
		Work = Work + TxtKoum1.value + LRSpcFill(FRTrim(TxtName.value),20,1) + JaLF;
		Work = Work + TxtKoum2.value + LRSpcFill(JaESC + 'F0' + FRTrim(TxtHakkoubi.value),20,1) + JaLF;
		Work = Work + JaESC + 'F1' + TxtKoum3.value + LRSpcFill(JaESC + 'F0' + FRTrim(TxtRiyoubi.value),20,1) + CharFill(0x20,1) + JaESC + 'F3' + TxtRiyouKaisu.value + JaLF;
		Work = Work + JaESC + 'F1' + TxtKoum4.value + JaESC + 'e12' + LRSpcFill(JaESC + 'F3' + FRTrim(TxtKonkaiPoint.value),9,1) + TxtP2.value + JaLF + JaLF;
		Work = Work + JaESC + 'e11' + JaESC + 'F1' + TxtKoum5.value + JaESC + 'e22' + LRSpcFill(JaESC + 'F1' + FRTrim(TxtRuikeiPoint.value),9,1) + TxtP1.value + JaLF + JaLF;
		if(PageMode == 1){
			Work = Work + JaESC + 'e11' + JaESC + 'Y266' +JaESC + 'D2' + JaESC + 'd0' + TxtComment0.value + JaLF;
			Work = Work + JaESC + 'Y290' + TxtComment1.value + JaLF;
			Work = Work + JaESC + 'Y317' + TxtComment2.value + JaLF;
			Work = Work + JaESC + 'Y344' + TxtComment3.value + JaLF;
			Work = Work + JaESC + 'Y380' + TxtComment4.value + JaLF;
			Work = Work + JaESC + 'Y407' + TxtComment5.value + JaLF;
			Work = Work + JaESC + 'Y434' + TxtComment6.value;
		}

		//alert(getByteCount(Work));
		PCCAx.SendData = Work;
//		alert(PCCAx.SendData);
		
		Rtn = PCCAx.pcxSendCommandRR(1, 3000);
//		APIReturnCode(Rtn)
//		alert('pcxSendCommandRR_PD = ' + Rtn);
		
//-kanazumi 	PCCAx.SendData = 'PO';
//-kanazumi		Rtn = PCCAx.pcxSendCommandRR(1, 10000);
//-kanazumi		APIReturnCode(Rtn)
//-kanazumi		alert('pcxSendCommandRR_PO = ' + Rtn);
		
//		Rtn = PCCAx.pcxReceiveResponse(0, 3000);
//		APIReturnCode(Rtn)
//		alert('pcxReceiveResponse = ' + Rtn);
		
		//alert('\"' + LRSpcFill(''+eval('08'),2,1) + '\"');
		
	}
}

function DTMake(){
	var Work ='';	// 
	var Tr1 = '';	// トラック１情報
	var Tr3 = '';	// トラック３情報
	var kb = '';	// 会員番号ワーク変数
	var nm = '';	// 名前変数
	var rb = '';	// 利用日ワーク変数
	var hb = '';	// 発行日ワーク変数
	var kp = '';	// 今回ポイントワーク変数
	var rp = '';	// 累計ポイントワーク変数
	var rk = '';	// 来店回数

	with (parent.SubMain.document.FrontPage_Form1) {
		// ポーリング実行
		Rtn = PCCAx.pcxReceiveResponse(0, 3000);
		APIReturnCode(Rtn)

		// 'DT'コマンド実行(ﾄﾗｯｸ1)
		PCCAx.SendData = 'DT:1';
		Rtn = PCCAx.pcxSendCommandRR(1, 3000);
		APIReturnCode(Rtn)

		Tr1 = PCCAx.PollCmdResData;
//		alert('Tr1 = ' + Tr1);

		// ポーリング実行
		Rtn = PCCAx.pcxReceiveResponse(0, 3000);
		APIReturnCode(Rtn)

		// 'DT'コマンド実行(ﾄﾗｯｸ3)
		PCCAx.SendData = 'DT:3';
		Rtn = PCCAx.pcxSendCommandRR(1, 3000);
		APIReturnCode(Rtn)

		Tr3 = PCCAx.PollCmdResData;
//		alert('Tr3 = ' + Tr3);

		// トラック１情報抜き取り
		kb = FRTrim(PCCAx.pcxCharAscHConv(1,substrB(Tr1,2,40)));	// 会員番号抜き出し
		nm = FRTrim(PCCAx.pcxCharAscHConv(1,PCCAx.pcxJISconvSJIS(0,PCCAx.pcxCharAscHConv(0,FRTrim(PCCAx.pcxCharAscHConv(1,substrB(Tr1,42,48))))))); // 名前抜き出し
//		rb = FRTrim(PCCAx.pcxCharAscHConv(1,substrB(Tr1,90,40)));	// 利用日抜き出し

		// トラック３情報抜き取り
		hb = FRTrim(PCCAx.pcxCharAscHConv(1,substrB(Tr3,2,40)));	// 発行日抜き出し
		kp = FRTrim(PCCAx.pcxCharAscHConv(1,substrB(Tr3,42,14)));	// 今回加算ポイント合計抜き出し
		rp = FRTrim(PCCAx.pcxCharAscHConv(1,substrB(Tr3,56,14)));	// 今回処理後の累計ポイント抜き出し
		rk = FRTrim(PCCAx.pcxCharAscHConv(1,substrB(Tr3,70,4)));	// 来店回数抜き出し

		// Tr1 データをメイン画面のTextへ設定(会員番号 + 最終カード利用日 + 加算ﾎﾟｲﾝﾄ合計 + 累計ﾎﾟｲﾝﾄ + 当日来店回数)
		TxtKanin.value       = kb; // 会員番号
		TxtName.value        = nm; // 名前
//		TxtRiyoubi.value     = rb; // 利用日
		TxtHakkoubi.value    = hb; // 発行日
//		TxtKonkaiPoint.value = kp; // 今回ﾎﾟｲﾝﾄ
		TxtRuikeiPoint.value = rp; // 累計ﾎﾟｲﾝﾄ
		TxtRiyouKaisu.value  = rk; // 来店回数
		//alert('\"' + LRSpcFill(''+eval('08'),2,1) + '\"');
	}
}
